import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:get/get_core/src/get_main.dart';
import 'package:mypoint_flutter_app/screen/home/custom_widget/scrollable_header.dart';

import '../../../shared/router_gage.dart';
import '../../voucher/sub_widget/voucher_section_title.dart';
import '../home_tab_viewmodel.dart';
import '../models/achievement_model.dart';
import '../models/main_service_model.dart';
import 'achievement_carousel_widget.dart';
import 'banner_carousel_widget.dart';
import 'main_service_grid_widget.dart';

class HomeScreenWithHeader extends StatefulWidget {
  const HomeScreenWithHeader({super.key});

  @override
  State<HomeScreenWithHeader> createState() => _HomeScreenWithHeaderState();
}

class _HomeScreenWithHeaderState extends State<HomeScreenWithHeader> {
  String backgroundImage = 'https://images.unsplash.com/photo-1557683316-973673baf926?w=800';
  final HomeTabViewModel _viewModel = Get.put(HomeTabViewModel());

  bool _showHover = true;
  List<MainServiceModel> _services = [];
  List<AchievementModel> _achievements = [];

  @override
  void initState() {
    super.initState();
    loadMainServicesFromAsset().then((list) {
      setState(() => _services = list);
    });
    loadMainAchievementsFromAsset().then((list) {
      setState(() => _achievements = list);
    });
  }

  // Sample data
  final String userName = 'Khánh';
  final int coinCount = 100;
  final int messageCount = 8;
  final String userRank = 'Hạng Đồng';

  void _changeBackground() {
    final List<String> backgrounds = [
      'https://images.unsplash.com/photo-1557683316-973673baf926?w=800',
      'https://images.unsplash.com/photo-1579952363873-27d3bfad9c0d?w=800',
      'https://images.unsplash.com/photo-1506905925346-21bda4d32df4?w=800',
      'https://images.unsplash.com/photo-1441974231531-c6227db76b6e?w=800',
      'https://images.unsplash.com/photo-1469474968028-56623f02e42e?w=800',
    ];

    setState(() {
      backgroundImage = backgrounds[(backgrounds.indexOf(backgroundImage) + 1) % backgrounds.length];
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SafeArea(
        top: false, // Cho phép content hiển thị dưới status bar
        child: CustomScrollView(
          physics: BouncingScrollPhysics(), // Hiệu ứng bounce khi scroll
          slivers: [
            // Scrollable Header
            ScrollableHeader(
              backgroundImageUrl: backgroundImage,
              userName: userName,
              coinCount: coinCount,
              messageCount: messageCount,
              userRank: userRank,
              onSearchTap: () {
                ScaffoldMessenger.of(context).showSnackBar(SnackBar(content: Text('Search tapped')));
              },
              onNotificationTap: () {
                ScaffoldMessenger.of(context).showSnackBar(SnackBar(content: Text('Notification tapped')));
              },
              onCoinTap: () {
                ScaffoldMessenger.of(context).showSnackBar(SnackBar(content: Text('Coin: $coinCount')));
              },
              onMessageTap: () {
                ScaffoldMessenger.of(context).showSnackBar(SnackBar(content: Text('Messages: $messageCount')));
              },
              onRankTap: () {
                ScaffoldMessenger.of(context).showSnackBar(SnackBar(content: Text('Rank: $userRank')));
              },
            ),

            // Content area
            SliverToBoxAdapter(
              child: Container(
                color: Colors.white,
                child: Column(
                  children: [
                    BannerCarousel(banners: [],),
                    if (_services.isNotEmpty)
                      MainServiceGrid(
                        services: _services,
                        onTap: (item) {
                          print("Tapped: ${item.serviceName}");
                        },
                      ),
                    if (_achievements.isNotEmpty)
                      HeaderSectionTitle(
                        title: 'Sự kiện MyPoint',
                        onViewAll: () {
                          Get.toNamed(vouchersScreen, arguments: {"isHotProduct": true});
                        },
                      ),
                    if (_achievements.isNotEmpty)
                      AchievementCarousel(
                        items: _achievements,
                        onTap: (item) {
                          // xử lý khi nhấn vào card
                        },
                      ),

                    // Sample content
                    ...List.generate(20, (index) => _buildContentCard(index)),

                    // Bottom padding
                    SizedBox(height: 20),
                  ],
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildContentCard(int index) {
    return Container(
      margin: EdgeInsets.symmetric(horizontal: 16, vertical: 8),
      padding: EdgeInsets.all(16),
      decoration: BoxDecoration(
        color: Colors.white,
        borderRadius: BorderRadius.circular(12),
        boxShadow: [BoxShadow(color: Colors.black.withOpacity(0.1), blurRadius: 8, offset: Offset(0, 2))],
      ),
      child: Row(
        children: [
          Container(
            width: 50,
            height: 50,
            decoration: BoxDecoration(color: Colors.red[400]!.withOpacity(0.1), borderRadius: BorderRadius.circular(8)),
            child: Icon(Icons.card_giftcard, color: Colors.red[400]),
          ),
          SizedBox(width: 16),
          Expanded(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  'Nội dung ${index + 1}',
                  style: TextStyle(fontSize: 16, fontWeight: FontWeight.w600, color: Colors.black87),
                ),
                SizedBox(height: 4),
                Text(
                  'Mô tả chi tiết cho nội dung số ${index + 1}',
                  style: TextStyle(fontSize: 14, color: Colors.grey[600]),
                ),
              ],
            ),
          ),
          Icon(Icons.arrow_forward_ios, color: Colors.grey[400], size: 16),
        ],
      ),
    );
  }

  Future<List<MainServiceModel>> loadMainServicesFromAsset() async {
    final jsonStr = await rootBundle.loadString('assets/data/main_services.json');
    final json = jsonDecode(jsonStr);
    final List list = json['data'];
    return list.map((e) => MainServiceModel.fromJson(e)).toList();
  }

  Future<List<AchievementModel>> loadMainAchievementsFromAsset() async {
    final jsonStr = await rootBundle.loadString('assets/data/main_achievements.json');
    final json = jsonDecode(jsonStr);
    final List list = json['data'];
    return list.map((e) => AchievementModel.fromJson(e)).toList();
  }
}
