import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import '../../widgets/custom_app_bar.dart';
import 'location_address_viewmodel.dart';

enum LocationAddressType {
  province,
  district;

  static LocationAddressType? fromString(String? value) {
    if (value == null) return null;
    return values.cast<LocationAddressType?>().firstWhere(
          (e) => e?.key == value,
      orElse: () => null,
    );
  }

  String get key {
    switch (this) {
      case LocationAddressType.province:
        return 'province';
      case LocationAddressType.district:
        return 'district';
    }
  }
}

class LocationAddressScreen extends StatefulWidget {
  const LocationAddressScreen({super.key});

  @override
  State<LocationAddressScreen> createState() => _LocationAddressScreenState();
}

class _LocationAddressScreenState extends State<LocationAddressScreen> {
  late final LocationAddressViewModel viewModel;
  final ScrollController scrollController = ScrollController();

  @override
  void initState() {
    super.initState();
    final args = Get.arguments ?? {};
    var typeRaw = args['type'] as String?;
    var selectedCode = args['selectedCode'] as String? ?? '';
    var type = LocationAddressType.fromString(typeRaw) ?? LocationAddressType.province;
    viewModel = Get.put(LocationAddressViewModel(
      type: type,
      provinceCode: args['provinceCode'] ?? '',
    ));
    viewModel.selectedCode.value = selectedCode;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: CustomAppBar.back(title: "Location Address"),
      // backgroundColor: Colors.transparent,
      body: SafeArea(
        child: Column(
          children: [
            Container(
              margin: const EdgeInsets.all(8),
              padding: const EdgeInsets.all(4),
              decoration: BoxDecoration(
                color: Colors.grey.shade200,
                borderRadius: const BorderRadius.all(Radius.circular(16)),
              ),
              child: TextField(
                decoration: const InputDecoration(
                  hintText: "Tìm kiếm",
                  prefixIcon: Icon(Icons.search_outlined),
                  border: InputBorder.none,
                ),
                onChanged: (value) {
                  viewModel.search(value);
                },
              ),
            ),
            const Divider(height: 1),
            Expanded(
              child: Obx(() {
                final items = viewModel.displayItems;
                // Scroll đến vị trí selected sau khi hiển thị list
                WidgetsBinding.instance.addPostFrameCallback((_) {
                  final index = items.indexWhere((e) => e.code == viewModel.selectedCode.value);
                  if (index != -1 && scrollController.hasClients) {
                    scrollController.animateTo(
                      index * 48.0, // chiều cao mỗi item
                      duration: const Duration(milliseconds: 300),
                      curve: Curves.easeInOut,
                    );
                  }
                });
                return ListView.separated(
                  controller: scrollController,
                  itemCount: items.length,
                  separatorBuilder: (_, __) => const Divider(height: 1),
                  itemBuilder: (context, index) {
                    final item = items[index];
                    final isSelected = viewModel.selectedCode.value == item.code;
                    return ListTile(
                      title: Text(item.name ?? '', style: TextStyle(color: isSelected ? Colors.blue : Colors.black87)),
                      trailing: isSelected ? const Icon(Icons.check, color: Colors.blue) : null,
                      onTap: () => viewModel.select(item),
                    );
                  },
                );
              }),
            ),
          ],
        ),
      ),
    );
  }
}
