import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:mypoint_flutter_app/widgets/back_button.dart';
import 'package:webview_flutter/webview_flutter.dart';
import '../../base/base_screen.dart';
import '../../base/basic_state.dart';

class BaseWebViewInput {
  final String? title;
  final String url;
  final bool isFullScreen;

  const BaseWebViewInput({this.title, required this.url, this.isFullScreen = false});
}

class BaseWebViewScreen extends BaseScreen {
  const BaseWebViewScreen({super.key});

  @override
  State<BaseWebViewScreen> createState() => _BaseWebViewScreenState();
}

class _BaseWebViewScreenState extends BaseState<BaseWebViewScreen> with BasicState {
  late final BaseWebViewInput input;
  late final WebViewController _controller;
  String? _dynamicTitle;

  @override
  void initState() {
    super.initState();
    final args = Get.arguments;
    if (args is BaseWebViewInput) {
      input = args;
    } else {
      WidgetsBinding.instance.addPostFrameCallback((_) {
        Get.back();
      });
      return;
    }
    _controller =
        WebViewController()
          ..setJavaScriptMode(JavaScriptMode.unrestricted)
          ..setBackgroundColor(Colors.transparent)
          ..setNavigationDelegate(
            NavigationDelegate(
              onPageFinished: (_) async {
                final title = await _controller.getTitle();
                setState(() {
                  _dynamicTitle = title;
                });
              },
              onWebResourceError: (error) {
                showAlertError(content: error.description);
              },
            ),
          )
          ..loadRequest(Uri.parse(input.url));
    _clearCookies();
  }

  @override
  Widget createBody() {
    return Scaffold(
      appBar:
          input.isFullScreen
              ? null
              : AppBar(
                title: Text(
                  input.title ?? _dynamicTitle ?? Uri.parse(input.url).host,
                  style: const TextStyle(fontSize: 16),
                ),
                leading: CustomBackButton(onPressed: _handleBack),
              ),
      body: SafeArea(
        child: WebViewWidget(
          controller: _controller,
          gestureRecognizers: const <Factory<OneSequenceGestureRecognizer>>{
            Factory<VerticalDragGestureRecognizer>(
              VerticalDragGestureRecognizer.new,
            ),
          },
        ),
      ),
    );
  }

  Future<void> _clearCookies() async {
    final cookieManager = WebViewCookieManager();
    await cookieManager.clearCookies();
  }

  void _handleBack() async {
    if (await _controller.canGoBack()) {
      _controller.goBack();
    } else {
      if (context.mounted) Navigator.of(context).pop();
    }
  }
}
